@@ -432,7 +432,6 @@ class CoSMoS_SFINCS(Model):
         post_path = os.path.join(self.cycle_path,
                                  "post")
             
-        nc_file = os.path.join(output_path, "sfincs_his.nc")
         
         # if not self.domain.input.tref:
         #     # This model has been run before. The model instance has not data on tref, obs points etc.
@@ -442,6 +441,11 @@ class CoSMoS_SFINCS(Model):
         #     self.domain.read_observation_points()
         
         if self.station:
+
+            if self.domain.input.outputformat=="bin":
+                nc_file = os.path.join(output_path, "zst.txt")
+            else:    
+                nc_file = os.path.join(output_path, "sfincs_his.nc")
             
             # if not self.domain.observation_point:
             #     obs_file = os.path.join(input_path, "sfincs.obs")
@@ -463,11 +467,12 @@ class CoSMoS_SFINCS(Model):
                           float_format='%.3f')        
 
         # Make flood map tiles
+#        if cosmos.config.make_flood_maps and self.make_flood_map and self.domain.input.outputformat=="bin":
         if cosmos.config.make_flood_maps and self.make_flood_map:
 
             flood_map_path = os.path.join(cosmos.scenario.path,
-                                       "tiles",   
-                                       "floodmap")
+                                          "tiles",   
+                                          "flood_map")
             
             index_path = os.path.join(self.path, "tiling", "indices")
             topo_path = os.path.join(self.path, "tiling", "topobathy")
@@ -481,8 +486,14 @@ class CoSMoS_SFINCS(Model):
                 # zsmax = self.domain.read_zsmax(zsmax_file = os.path.join(output_path, "zsmax.dat"),
                 #                                time_range=[t0.replace(tzinfo=None),
                 #                                            t1.replace(tzinfo=None)])
-                zsmax_file = os.path.join(output_path, "zsmax.dat")
-                zsmax = self.domain.read_zsmax(zsmax_file=zsmax_file)
+                
+                if self.domain.input.outputformat[0:3]=="bin":                
+                    zsmax_file = os.path.join(output_path, "zsmax.dat")
+                    zsmax = self.domain.read_zsmax(zsmax_file=zsmax_file)
+                else:
+                    zsmax_file = os.path.join(output_path, "sfincs_map.nc")
+                    zsmax = self.domain.read_zsmax(zsmax_file=zsmax_file)
+                    
 
 #                # Difference between MSL and NAVD88 (used in topo data)
 #                zsmax -= 0.067 
