@@ -5,7 +5,7 @@ Created on Mon May 10 14:36:35 2021
 @author: ormondt
 """
 
-from cosmos import cosmos
+from cosmos.cosmos_main import cosmos
 
 # Run cosmos_addpaths.py before executing run_cosmos.py
 
@@ -17,7 +17,7 @@ main_path = "d:\\cosmos"
 
 scenario_name = "hurricane_michael_coamps"
 
-cosmos.initialize(main_path, scenario_name)
+cosmos.initialize(main_path)
 
 cosmos.run(mode="single_shot",
            run_models=True,
